%global python3_pkgversion 39
%global srcname requests_ntlm

# No python39-flask
%bcond_with check

Name:           python%{python3_pkgversion}-%{srcname}-epel
Version:        1.1.0
Release:        1%{?dist}
Summary:        NTLM module for python requests (requires md4, thus legacy OpenSSL settings)

License:        ISC
URL:            https://pypi.python.org/pypi/requests_ntlm
Source0:        https://github.com/requests/requests-ntlm/archive/v%{version}/%{srcname}-%{version}.tar.gz
BuildArch:      noarch

%global _description %{expand:
This package allows Python clients running on any operating system to provide
NTLM authentication to a supporting server.

With OpenSSL 3 or above, this needs to set the legacy OpenSSL provider in
order to support md4 in Python.}

%description %{_description}

%package -n     python%{python3_pkgversion}-%{srcname}
Summary:        %{summary}
BuildRequires:  python%{python3_pkgversion}-devel
BuildRequires:  python3.9dist(setuptools)
BuildRequires:  python3.9dist(requests) >= 2
BuildRequires:  python3.9dist(ntlm-auth) >= 1.0.2
BuildRequires:  python3.9dist(cryptography) >= 1.3
BuildRequires:  python3.9dist(pytest)
%if %{with check}
BuildRequires:  python3.9dist(flask)
%endif

%description -n python%{python3_pkgversion}-%{srcname} %{_description}

Python 3 version.

%prep
%autosetup -n requests-ntlm-%{version}

%build
%py3_build

%install
%py3_install

%if %{with check}
%check
%python3 -m tests.test_server &
%python3 -m pytest --ignore=tests/functional/test_functional.py --ignore=tests/test_server.py -vv -k 'not (TestRequestsNtlm and not username)'

# see https://github.com/jborean93/ntlm-auth/issues/22
cat > openssl.cnf << EOF
openssl_conf = openssl_init

[openssl_init]
providers = provider_sect

[provider_sect]
default = default_sect
legacy = legacy_sect

[default_sect]
activate = 1

[legacy_sect]
activate = 1
EOF
export OPENSSL_CONF=${PWD}/openssl.cnf
%python3 -m pytest --ignore=tests/functional/test_functional.py --ignore=tests/test_server.py -vv -k '(TestRequestsNtlm and not username)'
%endif

%files -n python%{python3_pkgversion}-%{srcname}
%license LICENSE
%doc CONTRIBUTORS.rst README.rst
%{python3_sitelib}/%{srcname}/
%{python3_sitelib}/%{srcname}-*.egg-info/

%changelog
* Tue Nov 08 2022 Orion Poplawski <orion@nwra.com> - 1.1.0-1
- Build for EPEL with Python 3.9
